@@ -1,64 +1,75 @@
 import dataclasses
+import logging
+import subprocess
 from pathlib import Path
-from typing import Optional
 
 from bx_py_utils.dict_utils import dict_get
+from cli_base.cli_tools.git import Git, GitError, NoGitRepoError
+from cli_base.cli_tools.subprocess_utils import ToolsExecutor as OriginalToolsExecutor
 from editorconfig import EditorConfigError, get_properties
 from packaging.specifiers import SpecifierSet
 from packaging.version import Version
 from rich import print  # noqa
 from rich.pretty import pprint
 
-from manageprojects.constants import FORMAT_PY_FILE_DEFAULT_MAX_LINE_LENGTH, FORMAT_PY_FILE_DEFAULT_MIN_PYTON_VERSION
+from manageprojects.constants import FORMAT_PY_FILE_DEFAULT_MAX_LINE_LENGTH, FORMAT_PY_FILE_DEFAULT_MIN_PYTHON_VERSION
 from manageprojects.exceptions import NoPyProjectTomlFound
-from manageprojects.git import Git, GitError, NoGitRepoError
 from manageprojects.utilities.pyproject_toml import TomlDocument, get_pyproject_toml
-from manageprojects.utilities.subprocess_utils import ToolsExecutor
 
 
+logger = logging.getLogger(__name__)
+
 MAX_PY3_VER = 15
 
 
+class ToolsExecutor(OriginalToolsExecutor):
+    def verbose_check_call(self, *args, **kwargs):
+        try:
+            super().verbose_check_call(*args, **kwargs)
+        except subprocess.CalledProcessError:
+            pass  # Info print is already done
+
+
 @dataclasses.dataclass
 class GitInfo:
-    cwd: Path
+    git: Git
     main_branch_name: str
 
 
 @dataclasses.dataclass
 class PyProjectInfo:
     py_min_ver: Version
-    pyproject_toml_path: Optional[Path] = None
-    raw_py_ver_req: Optional[str] = None
+    pyproject_toml_path: Path | None = None
+    raw_py_ver_req: str | None = None
 
 
 @dataclasses.dataclass
 class Config:
-    git_info: Optional[GitInfo]
+    git_info: GitInfo | None
     pyproject_info: PyProjectInfo
     max_line_length: int
 
     @property
-    def py_ver_str(self) -> Optional[str]:
+    def py_ver_str(self) -> str | None:
         if pyproject_info := self.pyproject_info:
             return f'py{pyproject_info.py_min_ver.major}{pyproject_info.py_min_ver.minor}'
 
     @property
-    def project_root_path(self) -> Optional[Path]:
+    def project_root_path(self) -> Path | None:
         if git_info := self.git_info:
-            if cwd := git_info.cwd:
+            if cwd := git_info.git.cwd:
                 return cwd
 
         if pyproject_toml_path := self.pyproject_info.pyproject_toml_path:
             return pyproject_toml_path.parent
 
     @property
-    def main_branch_name(self) -> Optional[str]:
+    def main_branch_name(self) -> str | None:
         if git_info := self.git_info:
             return git_info.main_branch_name
 
 
-def get_git_info(file_path: Path) -> Optional[GitInfo]:
+def get_git_info(file_path: Path) -> GitInfo | None:
     try:
         git = Git(cwd=file_path.parent, detect_root=True)
     except NoGitRepoError:
@@ -71,12 +82,12 @@ def get_git_info(file_path: Path) -> Optional[GitInfo]:
         else:
             print(f'Git main branch name: {main_branch_name!r} from: {git.cwd}')
             return GitInfo(
-                cwd=git.cwd,
+                git=git,
                 main_branch_name=main_branch_name,
             )
 
 
-def get_py_min_version(raw_py_ver_req) -> Optional[Version]:
+def get_py_min_version(raw_py_ver_req) -> Version | None:
     specifier = SpecifierSet(raw_py_ver_req)
 
     # FIXME: How can this been simpler?
@@ -121,7 +132,7 @@ def get_pyproject_info(file_path: Path, default_min_py_version: str) -> PyProjec
     return pyproject_info
 
 
-def get_editorconfig_max_line_length(file_path) -> Optional[int]:
+def get_editorconfig_max_line_length(file_path) -> int | None:
     try:
         options = get_properties(file_path)
     except EditorConfigError as err:
@@ -138,7 +149,7 @@ def get_editorconfig_max_line_length(file_path) -> Optional[int]:
 
 def get_config(
     file_path,
-    default_min_py_version=FORMAT_PY_FILE_DEFAULT_MIN_PYTON_VERSION,
+    default_min_py_version=FORMAT_PY_FILE_DEFAULT_MIN_PYTHON_VERSION,
     default_max_line_length=FORMAT_PY_FILE_DEFAULT_MAX_LINE_LENGTH,
 ) -> Config:
     config = Config(
@@ -150,79 +161,123 @@ def get_config(
     return config
 
 
-def run_pyupgrade(tools_executor, file_path, config):
-    pyver_arg = f'--{config.py_ver_str}-plus'
-    tools_executor.verbose_check_output(
-        'pyupgrade',
-        '--exit-zero-even-if-changed',
-        pyver_arg,
-        file_path,
-    )
-
-
-def run_darker(tools_executor, file_path, config, darker_prefixes):
-    if darker_prefixes:
-        # darker/black will not fix e.g.:
-        #   "E302 expected 2 blank lines"
-        #   "E303 too many blank lines (4)"
-        # work-a-round: run autopep8 only for these fixes ;)
-        tools_executor.verbose_check_output(
-            'autopep8',
-            '--ignore-local-config',
-            '--select',
-            darker_prefixes,
-            f'--max-line-length={config.max_line_length}',
-            '--in-place',
-            str(file_path),
-        )
-
-    tools_executor.verbose_check_output(
-        'darker',
-        '--flynt',
-        '--isort',
-        '--skip-string-normalization',
-        '--revision',
-        f'{config.main_branch_name}...',
-        '--line-length',
-        str(config.max_line_length),
+def format_complete_file(tools_executor, file_path, config: Config):
+    tools_executor.verbose_check_call(
+        'ruff',
+        'format',
         '--target-version',
         config.py_ver_str,
         file_path,
     )
 
 
-def run_autopep8(tools_executor, file_path, config):
-    tools_executor.verbose_check_output(
-        'autopep8',
-        '--ignore-local-config',
-        '--max-line-length',
-        str(config.max_line_length),
-        '--aggressive',
-        '--aggressive',
-        '--in-place',
+def parse_ranges(git_diff_output: str) -> list:
+    line_changes = []
+    for line in git_diff_output.splitlines():
+        if not line.startswith('@@'):
+            continue
+
+        line_infos = line.split('@@')[1].strip().split(' ')
+        temp = []
+        for line_info in line_infos:
+            line_info = line_info.strip('+-')
+            if ',' in line_info:
+                start_line, line_count = map(int, line_info.split(','))
+            else:
+                start_line, line_count = int(line_info), 1
+
+            if start_line == 0:
+                start_line = 1  # ruff starts line numbers from 1, not 0
+
+            temp.append(start_line)
+            temp.append(start_line + line_count)
+        line_changes.append((min(temp), max(temp)))
+    return line_changes
+
+
+def merge_ranges(ranges: list, max_distance: int = 1) -> list:
+    """
+    >>> merge_ranges([(1,2), (3,4), (10,11), (20, 25), (21, 26)])
+    [(1, 4), (10, 11), (20, 26)]
+    """
+    merged = []
+    for start, end in sorted(ranges):
+        if merged and start - merged[-1][1] <= max_distance:
+            # Extend the last range if within max_distance
+            merged[-1] = (merged[-1][0], max(end, merged[-1][1]))
+        else:
+            # Otherwise, add a new range
+            merged.append((start, end))
+    return merged
+
+
+def format_only_changed_lines(tools_executor, file_path, config: Config, max_distance=2):
+    # Use darker after v3 release, see: https://github.com/akaihola/darker/milestones
+
+    git: Git = config.git_info.git
+    target = f'origin/{config.main_branch_name}'
+
+    git_diff_output = git.git_verbose_check_output('diff', target, '--unified=0', file_path)
+    logger.debug('Git diff output: %s', git_diff_output)
+    ranges = parse_ranges(git_diff_output)
+    print(f'All git diff code ranges: {ranges}')
+
+    if not ranges:
+        # TODO: Check if file is part of git repository:
+        #       If not, then format it. If yes, then skip.
+        tools_executor.verbose_check_call(
+            'ruff',
+            'format',
+            '--target-version',
+            config.py_ver_str,
+            file_path,
+            verbose=False,
+        )
+    else:
+        print('Apply code formatter only to changed lines (in reversed order):')
+        ranges = merge_ranges(ranges, max_distance=max_distance)
+        for start, end in reversed(ranges):
+            print(f'Processing range: {start} - {end}', end=' - ')
+            tools_executor.verbose_check_call(
+                'ruff',
+                'format',
+                '--target-version',
+                config.py_ver_str,
+                file_path,
+                f'--range={start}-{end}',
+                verbose=False,
+            )
+
+    print('\n\nFix imports and remove unused imports:')
+    tools_executor.verbose_check_call(
+        'ruff',
+        'check',
+        '--target-version',
+        config.py_ver_str,
+        '--select',
+        'I001,F401',  # I001: Import sorting (from isort) + F401: Unused imports (from pyflakes)
+        '--fix',
+        '--unsafe-fixes',
         file_path,
     )
 
 
-def run_flake8(tools_executor, file_path, config):
-    tools_executor.verbose_check_output(
-        'flake8',
-        '--max-line-length',
-        str(config.max_line_length),
+def run_file_check(tools_executor, file_path, config: Config):
+    tools_executor.verbose_check_call(
+        'ruff',
+        'check',
+        '--target-version',
+        config.py_ver_str,
         file_path,
     )
 
 
-def run_pyflakes(tools_executor, file_path, config):
-    tools_executor.verbose_check_output('pyflakes', file_path)
+def run_codespell(tools_executor, file_path, config: Config):
+    tools_executor.verbose_check_call('codespell', file_path)
 
 
-def run_codespell(tools_executor, file_path, config):
-    tools_executor.verbose_check_output('codespell', file_path)
-
-
-def run_mypy(tools_executor, file_path, config):
-    tools_executor.verbose_check_output(
+def run_mypy(tools_executor, file_path, config: Config):
+    tools_executor.verbose_check_call(
         'mypy',
         '--ignore-missing-imports',
         '--follow-imports',
@@ -236,7 +291,6 @@ def format_one_file(
     *,
     default_min_py_version: str,
     default_max_line_length: int,
-    darker_prefixes: str,
     file_path: Path,
 ) -> None:
     file_path = file_path.resolve()
@@ -261,15 +315,14 @@ def format_one_file(
 
     print('\n')
 
-    run_pyupgrade(tools_executor, file_path, config)
-
     if config.main_branch_name:
-        run_darker(tools_executor, file_path, config, darker_prefixes)
+        # We have a Git repository, so we can format only changed lines
+        format_only_changed_lines(tools_executor, file_path, config)
     else:
-        run_autopep8(tools_executor, file_path, config)
+        # Run full formatting the whole file
+        format_complete_file(tools_executor, file_path, config)
 
-    run_flake8(tools_executor, file_path, config)
-    run_pyflakes(tools_executor, file_path, config)
+    run_file_check(tools_executor, file_path, config)
     run_codespell(tools_executor, file_path, config)
     run_mypy(tools_executor, file_path, config)
 
