@@ -1,33 +1,24 @@
-from unittest.mock import patch
+import warnings
 
 import click
-import rich_click
-from bx_py_utils.path import assert_is_file
-from bx_py_utils.test_utils.context_managers import MassContextManager
+from cli_base.cli_tools.test_utils.rich_test_utils import NoColorEnvRich
 from click.testing import CliRunner, Result
 
-from manageprojects.utilities.subprocess_utils import verbose_check_output
-
 
 TERMINAL_WIDTH = 100
 
 
 def subprocess_cli(*, cli_bin, args, exit_on_error=True):
-    assert_is_file(cli_bin)
-    return verbose_check_output(
-        cli_bin,
-        *args,
-        cwd=cli_bin.parent,
-        extra_env=dict(TERMINAL_WIDTH=str(TERMINAL_WIDTH)),
-        exit_on_error=exit_on_error,
+    warnings.warn(
+        'Migrate to: NoColorRichClickCli context manager !',
+        DeprecationWarning,
+        stacklevel=2,
     )
+    from cli_base.cli_tools.test_utils.rich_click_test_utils import NoColorRichClickCli
 
-
-class ForceRichTerminalWidth(MassContextManager):
-    mocks = (
-        patch.object(rich_click.rich_click, 'MAX_WIDTH', TERMINAL_WIDTH),
-        patch.object(rich_click.rich_click, 'FORCE_TERMINAL', False),
-    )
+    with NoColorRichClickCli() as cm:
+        stdout = cm.invoke(cli_bin=cli_bin, args=args, exit_on_error=exit_on_error)
+    return stdout
 
 
 class ClickInvokeCliException(Exception):
@@ -36,12 +27,17 @@ class ClickInvokeCliException(Exception):
 
 
 def invoke_click(cli, *args, expected_stderr='', expected_exit_code=0, strip=True, **kwargs):
+    warnings.warn(
+        'Deprecated: Will be removed in future !',
+        DeprecationWarning,
+        stacklevel=2,
+    )
     assert isinstance(cli, click.Command)
 
     args = tuple([str(arg) for arg in args])  # e.g.: Path() -> str
 
-    with ForceRichTerminalWidth():
-        runner = CliRunner(mix_stderr=False)
+    with NoColorEnvRich(width=TERMINAL_WIDTH):
+        runner = CliRunner()
         result: Result = runner.invoke(cli=cli, args=args, **kwargs, color=False)
 
     if result.exception:
