@@ -5,17 +5,13 @@ from pathlib import Path
 import yaml
 from bx_py_utils.path import assert_is_dir, assert_is_file
 from bx_py_utils.test_utils.datetime import parse_dt
+from bx_py_utils.test_utils.redirect import RedirectOut
+from cli_base.cli_tools.test_utils.git_utils import init_git
+from cli_base.cli_tools.test_utils.logs import AssertLogs
 
-from manageprojects.cli.cli_app import clone_project
+from manageprojects import cli_app
 from manageprojects.cookiecutter_templates import start_managed_project, update_managed_project
-from manageprojects.data_classes import (
-    CookiecutterResult,
-    GenerateTemplatePatchResult,
-    ManageProjectsMeta,
-)
-from manageprojects.test_utils.click_cli_utils import invoke_click
-from manageprojects.test_utils.git_utils import init_git
-from manageprojects.test_utils.logs import AssertLogs
+from manageprojects.data_classes import CookiecutterResult, GenerateTemplatePatchResult, ManageProjectsMeta
 from manageprojects.tests.base import BaseTestCase
 from manageprojects.utilities.pyproject_toml import PyProjectToml
 from manageprojects.utilities.temp_path import TemporaryDirectory
@@ -70,14 +66,17 @@ class CookiecutterTemplatesTestCase(BaseTestCase):
             assert_is_file(replay_file_path)
             replay_json = replay_file_path.read_text()
             replay_data = json.loads(replay_json)
-            assert replay_data == {
-                'cookiecutter': {
+            self.assertEqual(
+                replay_data['cookiecutter'],
+                {
                     'dir_name': 'a_dir_name',
                     'file_name': 'a_file_name',
+                    '_checkout': None,
                     '_template': cookiecutter_template,
+                    '_repo_dir': str(git_path / directory),
                     '_output_dir': str(cookiecutter_output_dir),
-                }
-            }
+                },
+            )
 
             # Our replay config was used?
             assert_is_file(cookiecutter_output_dir / 'a_dir_name' / 'a_file_name.py')
@@ -112,15 +111,16 @@ class CookiecutterTemplatesTestCase(BaseTestCase):
             # Test clone a existing project
 
             cloned_path = main_temp_path / 'cloned_project'
-            with AssertLogs(self) as logs:
-                output = invoke_click(clone_project, project_path, cloned_path)
-                logs.assert_in(
-                    'Read existing pyproject.toml',
-                    "Call 'cookiecutter'",
-                    'Create new pyproject.toml',
-                )
+            with AssertLogs(self) as logs, RedirectOut() as buffer:
+                cli_app.main(args=('clone-project', str(project_path), str(cloned_path)))
+            logs.assert_in(
+                'Read existing pyproject.toml',
+                "Call 'cookiecutter'",
+                'Create new pyproject.toml',
+            )
+            self.assertEqual(buffer.stderr, '')
             end_path = cloned_path / 'a_dir_name'
-            self.assert_in_content(got=output, parts=(f'{project_path} successfully cloned to {end_path}',))
+            self.assert_in_content(got=buffer.stdout, parts=(f'{project_path} successfully cloned to {end_path}',))
 
             # pyproject.toml created?
             with AssertLogs(self, loggers=('manageprojects',)) as logs:
