@@ -2,8 +2,11 @@ import inspect
 from pathlib import Path
 from unittest import TestCase
 
+from cli_base.cli_tools.test_utils.logs import AssertLogs
 from packaging.version import Version
 
+from manageprojects.cli_dev import PACKAGE_ROOT
+from manageprojects.constants import PY_BIN_PATH
 from manageprojects.format_file import (
     Config,
     GitInfo,
@@ -13,16 +16,47 @@ from manageprojects.format_file import (
     get_editorconfig_max_line_length,
     get_git_info,
     get_pyproject_info,
+    parse_ranges,
 )
-from manageprojects.test_utils.logs import AssertLogs
-from manageprojects.test_utils.subprocess import SubprocessCallMock
-from manageprojects.tests.base import PROJECT_PATH
+from manageprojects.test_utils.subprocess import SimpleRunReturnCallback, SubprocessCallMock
+from manageprojects.tests.base import GIT_BIN_PARENT
 from manageprojects.utilities.temp_path import TemporaryDirectory
 
 
 class FormatFileTestCase(TestCase):
+    maxDiff = None
+
+    def test_parse_ranges(self):
+        git_diff_output = inspect.cleandoc("""
+            diff --git a/manageprojects/format_file.py b/manageprojects/format_file.py
+            index 0d480a8..1b29799 100644
+            --- a/manageprojects/format_file.py
+            +++ b/manageprojects/format_file.py
+            @@ -1,0 +2 @@ import dataclasses
+            +import re
+            @@ -32 +33 @@ class GitInfo:
+            -    cwd: Path
+            +    git: Git
+            @@ -293,6 +259,0 @@ def format_one_file(
+            -    run_autoflake(
+            -        tools_executor,
+            -        file_path,
+            -        config,
+            -        remove_all_unused_imports=remove_all_unused_imports,
+            -    )
+        """)
+        ranges = parse_ranges(git_diff_output)
+        self.assertEqual(
+            ranges,
+            [
+                (1, 3),
+                (32, 34),
+                (259, 299),
+            ],
+        )
+
     def test_get_git_info(self):
-        with AssertLogs(self, loggers=('manageprojects',)):
+        with AssertLogs(self, loggers=('cli_base',)):
             git_info = get_git_info(file_path=Path(__file__))
             self.assertIsInstance(git_info, GitInfo)
             self.assertEqual(git_info.main_branch_name, 'main')
@@ -73,12 +107,12 @@ class FormatFileTestCase(TestCase):
 
             pyproject_toml.write_text(
                 inspect.cleandoc(
-                    '''
+                    """
                     [tool.poetry.dependencies]
                     foo=1
                     python = '>=3.11,<4.0.0'
                     bar=2
-                    '''
+                    """
                 )
             )
             self.assertEqual(
@@ -92,10 +126,10 @@ class FormatFileTestCase(TestCase):
 
             pyproject_toml.write_text(
                 inspect.cleandoc(
-                    '''
+                    """
                     [project]
                     requires-python = ">=3.99,<4"
-                    '''
+                    """
                 )
             )
             self.assertEqual(
@@ -110,9 +144,9 @@ class FormatFileTestCase(TestCase):
         self.assertEqual(
             get_pyproject_info(file_path=Path(__file__), default_min_py_version='3.7'),
             PyProjectInfo(
-                pyproject_toml_path=PROJECT_PATH / 'pyproject.toml',
-                py_min_ver=Version('3.9'),
-                raw_py_ver_req='>=3.9,<4',
+                pyproject_toml_path=PACKAGE_ROOT / 'pyproject.toml',
+                py_min_ver=Version('3.11'),
+                raw_py_ver_req='>=3.11',
             ),
         )
 
@@ -122,17 +156,17 @@ class FormatFileTestCase(TestCase):
             self.assertIsNone(get_editorconfig_max_line_length(file_path=temp_path))
 
     def test_get_config(self):
-        with AssertLogs(self, loggers=('manageprojects',)):
+        with AssertLogs(self, loggers=('cli_base',)):
             config = get_config(file_path=Path(__file__))
             self.assertIsInstance(config, Config)
             self.assertEqual(
                 config,
                 Config(
-                    git_info=GitInfo(cwd=PROJECT_PATH, main_branch_name='main'),
+                    git_info=GitInfo(git=config.git_info.git, main_branch_name='main'),
                     pyproject_info=PyProjectInfo(
-                        pyproject_toml_path=PROJECT_PATH / 'pyproject.toml',
-                        py_min_ver=Version('3.9'),
-                        raw_py_ver_req='>=3.9,<4',
+                        pyproject_toml_path=PACKAGE_ROOT / 'pyproject.toml',
+                        py_min_ver=Version('3.11'),
+                        raw_py_ver_req='>=3.11',
                     ),
                     max_line_length=119,
                 ),
@@ -145,57 +179,80 @@ class FormatFileTestCase(TestCase):
                     Config(
                         git_info=None,
                         pyproject_info=PyProjectInfo(
-                            py_min_ver=Version('3.9'), pyproject_toml_path=None, raw_py_ver_req=None
+                            py_min_ver=Version('3.10'), pyproject_toml_path=None, raw_py_ver_req=None
                         ),
                         max_line_length=119,
                     ),
                 )
 
     def test_format_one_file(self):
-        with AssertLogs(self, loggers=('manageprojects',)), SubprocessCallMock() as call_mock:
+        with (
+            AssertLogs(self, loggers=('cli_base',)),
+            SubprocessCallMock(
+                return_callback=SimpleRunReturnCallback(
+                    stdout='* main',  # "git branch" call -> bach name found -> use Darker
+                )
+            ) as call_mock,
+        ):
             format_one_file(
                 default_min_py_version='3.11',
                 default_max_line_length=123,
-                darker_prefixes='E456,E789',
                 file_path=Path(__file__),
             )
 
         self.assertEqual(
-            call_mock.get_popenargs(rstrip_path=PROJECT_PATH),
+            call_mock.get_popenargs(rstrip_paths=(PY_BIN_PATH, GIT_BIN_PARENT)),
             [
+                ['.../git', 'branch', '--no-color'],
+                ['.../git', 'diff', 'origin/main', '--unified=0', 'manageprojects/tests/test_format_file.py'],
+                ['.../ruff', 'format', '--target-version', 'py311', 'manageprojects/tests/test_format_file.py'],
                 [
-                    '.../.venv/bin/pyupgrade',
-                    '--exit-zero-even-if-changed',
-                    '--py39-plus',
-                    'manageprojects/tests/test_format_file.py',
-                ],
-                [
-                    '.../.venv/bin/autopep8',
-                    '--ignore-local-config',
-                    '--select',
-                    'E456,E789',
-                    '--max-line-length=119',
-                    '--in-place',
-                    'manageprojects/tests/test_format_file.py',
-                ],
-                [
-                    '.../.venv/bin/darker',
-                    '--flynt',
-                    '--isort',
-                    '--skip-string-normalization',
-                    '--revision',
-                    'main...',
-                    '--line-length',
-                    '119',
+                    '.../ruff',
+                    'check',
                     '--target-version',
-                    'py39',
+                    'py311',
+                    '--select',
+                    'I001,F401',
+                    '--fix',
+                    '--unsafe-fixes',
                     'manageprojects/tests/test_format_file.py',
                 ],
-                ['.../.venv/bin/flake8', '--max-line-length', '119', 'manageprojects/tests/test_format_file.py'],
-                ['.../.venv/bin/pyflakes', 'manageprojects/tests/test_format_file.py'],
-                ['.../.venv/bin/codespell', 'manageprojects/tests/test_format_file.py'],
+                ['.../ruff', 'check', '--target-version', 'py311', 'manageprojects/tests/test_format_file.py'],
+                ['.../codespell', 'manageprojects/tests/test_format_file.py'],
                 [
-                    '.../.venv/bin/mypy',
+                    '.../mypy',
+                    '--ignore-missing-imports',
+                    '--follow-imports',
+                    'skip',
+                    '--allow-redefinition',
+                    'manageprojects/tests/test_format_file.py',
+                ],
+            ],
+        )
+
+        with (
+            AssertLogs(self, loggers=('cli_base',)),
+            SubprocessCallMock(
+                return_callback=SimpleRunReturnCallback(
+                    stdout='',  # No git branch name found -> Format the complete file
+                )
+            ) as call_mock,
+        ):
+            format_one_file(
+                default_min_py_version='3.11',
+                default_max_line_length=123,
+                file_path=Path(__file__),
+            )
+
+        self.assertEqual(
+            call_mock.get_popenargs(rstrip_paths=(PY_BIN_PATH, GIT_BIN_PARENT)),
+            [
+                ['.../git', 'branch', '--no-color'],
+                ['.../ruff', 'format', '--target-version', 'py311', 'manageprojects/tests/test_format_file.py'],
+                ['.../ruff', 'check', '--target-version', 'py311', 'manageprojects/tests/test_format_file.py'],
+                ['.../codespell', 'manageprojects/tests/test_format_file.py'],
+                [
+                    '.../mypy',
                     '--ignore-missing-imports',
                     '--follow-imports',
                     'skip',
