@@ -1,21 +1,33 @@
 import inspect
 import sys
+import tomllib
 from pathlib import Path
-from unittest import TestCase
 from unittest.mock import patch
 
+from bx_py_utils.test_utils.redirect import RedirectOut
+from cli_base.cli_tools import subprocess_utils
+from cli_base.cli_tools.test_utils.git_utils import init_git
+from cli_base.cli_tools.test_utils.logs import AssertLogs
+from cli_base.cli_tools.test_utils.rich_test_utils import NoColorEnvRich
 from packaging.version import Version
 
-from manageprojects.test_utils.git_utils import init_git
-from manageprojects.test_utils.logs import AssertLogs
+import manageprojects
+from manageprojects.cli_dev import PACKAGE_ROOT
 from manageprojects.test_utils.subprocess import FakeStdout, SubprocessCallMock
-from manageprojects.tests.base import GIT_BIN_PARENT
-from manageprojects.utilities import subprocess_utils
-from manageprojects.utilities.publish import PublisherGit, build, get_pyproject_toml_version
+from manageprojects.tests.base import GIT_BIN_PARENT, BaseTestCase
+from manageprojects.utilities.publish import (
+    PublisherGit,
+    build,
+    check_version,
+    clean_version,
+    get_pyproject_toml_version,
+    hatchling_dynamic_version,
+    setuptools_dynamic_version,
+)
 from manageprojects.utilities.temp_path import TemporaryDirectory
 
 
-class PublishTestCase(TestCase):
+class PublishTestCase(BaseTestCase):
     def test_build(self):
         def return_callback(popenargs, args, kwargs):
             return FakeStdout(stdout='Mocked run output')
@@ -26,7 +38,7 @@ class PublishTestCase(TestCase):
         self.assertEqual(
             call_mock.get_popenargs(rstrip_paths=(str(Path(sys.executable).parent),)),
             [
-                ['.../python', '-m', 'build'],
+                ['.../uv', 'build'],
             ],
         )
 
@@ -54,6 +66,17 @@ class PublishTestCase(TestCase):
             ],
         )
 
+    def setuptools_dynamic_version(self):
+        pyproject_toml_path = PACKAGE_ROOT / 'pyproject.toml'
+        pyproject_toml = tomllib.loads(pyproject_toml_path.read_text(encoding='UTF-8'))
+        setuptools_version = setuptools_dynamic_version(
+            pyproject_toml=pyproject_toml,
+            pyproject_toml_path=pyproject_toml_path,
+        )
+        self.assertIsNotNone(setuptools_version)
+        real_version = clean_version(manageprojects.__version__)
+        self.assertEqual(setuptools_version, real_version)
+
     def test_get_pyproject_toml_version(self):
         with TemporaryDirectory(prefix='test_get_pyproject_toml_version') as temp_path:
             pyproject_toml_path = temp_path / 'pyproject.toml'
@@ -90,7 +113,7 @@ class PublishTestCase(TestCase):
 
     def test_publisher_fast_checks_not_existing_tag(self):
         # https://github.com/jedie/manageprojects/issues/68
-        with AssertLogs(self, loggers=('manageprojects',)), TemporaryDirectory(
+        with AssertLogs(self, loggers=('cli_base',)), TemporaryDirectory(
             prefix='test_publisher_fast_checks_not_existing_tag'
         ) as temp_path:
             Path(temp_path, '1.txt').touch()
@@ -110,9 +133,7 @@ class PublishTestCase(TestCase):
             )
 
     def test_publisher_git(self):
-        with AssertLogs(self, loggers=('manageprojects',)), TemporaryDirectory(
-            prefix='test_publisher_git'
-        ) as temp_path:
+        with AssertLogs(self, loggers=('cli_base',)), TemporaryDirectory(prefix='test_publisher_git') as temp_path:
             Path(temp_path, '1.txt').touch()
             git, first_hash = init_git(temp_path, comment='The initial commit ;)')
 
@@ -186,3 +207,44 @@ class PublishTestCase(TestCase):
                     ['.../git', 'push', '--tags'],
                 ],
             )
+
+    def test_hatchling_dynamic_version(self):
+        pyproject_toml_path = PACKAGE_ROOT / 'pyproject.toml'
+        pyproject_toml = tomllib.loads(pyproject_toml_path.read_text())
+
+        version = hatchling_dynamic_version(
+            pyproject_toml=pyproject_toml,
+            pyproject_toml_path=PACKAGE_ROOT / 'pyproject.toml',
+        )
+        self.assertIsInstance(version, Version)
+        self.assertEqual(version, Version(manageprojects.__version__))
+
+    def test_check_version(self):
+        # Enforce matching versions:
+        with patch('manageprojects.utilities.publish.version', return_value=manageprojects.__version__):
+            module_version = check_version(
+                module=manageprojects,
+                package_path=PACKAGE_ROOT,
+            )
+        self.assertEqual(module_version, Version(manageprojects.__version__))
+
+        # Error case:
+        with (
+            NoColorEnvRich(),
+            RedirectOut() as buffer,
+            self.assertRaises(SystemExit),
+            patch('manageprojects.utilities.publish.version', return_value='0.1.2'),
+        ):
+            module_version = check_version(
+                module=manageprojects,
+                package_path=PACKAGE_ROOT,
+            )
+        self.assertEqual(module_version, Version(manageprojects.__version__))
+        self.assertEqual(buffer.stderr, '')
+        self.assert_in_content(
+            got=buffer.stdout,
+            parts=(
+                f'Version mismatch: current version {manageprojects.__version__} is not the installed one: 0.1.2',
+                '(Hint: Install package and run publish again)',
+            ),
+        )
