@@ -1,25 +1,35 @@
+import logging
 import shutil
+import sys
 import tempfile
 from collections.abc import Iterable
 from importlib.metadata import version
 from pathlib import Path
-from typing import Optional
 
-from bx_py_utils.dict_utils import dict_get
-from bx_py_utils.path import assert_is_file
+from packaging.version import Version
+from rich import print  # noqa
+
 
 try:
     import tomllib  # New in Python 3.11
 except ImportError:
     import tomli as tomllib
 
-import sys
+from bx_py_utils.dict_utils import dict_get
+from bx_py_utils.path import assert_is_file
+from cli_base.cli_tools.git import Git, GitError
+from cli_base.cli_tools.path_utils import which
+from cli_base.cli_tools.subprocess_utils import verbose_check_call, verbose_check_output
 
-from packaging.version import Version
-from rich import print  # noqa
 
-from manageprojects.git import Git, GitError
-from manageprojects.utilities.subprocess_utils import verbose_check_call, verbose_check_output
+logger = logging.getLogger(__name__)
+
+
+def get_uv_path() -> Path | None:
+    """
+    Look for the 'uv' executable first in venv bin and then in the PATH.
+    """
+    return which('uv')
 
 
 def exit_with_error(txt, hint=None):
@@ -138,7 +148,37 @@ def clean_version(version: str) -> Version:
     return Version(version)
 
 
-def get_pyproject_toml_version(package_path: Path) -> Optional[Version]:
+def setuptools_dynamic_version(*, pyproject_toml: dict, pyproject_toml_path: Path) -> Version | None:
+    dynamic = dict_get(pyproject_toml, 'project', 'dynamic')
+    if dynamic and 'version' in dynamic:
+        if dict_get(pyproject_toml, 'tool', 'setuptools', 'dynamic', 'version'):
+            # Project used "dynamic metadata" from setuptools for the version
+            from setuptools.config.pyprojecttoml import read_configuration
+
+            setuptools_pyproject_toml = read_configuration(pyproject_toml_path)
+            if ver_str := dict_get(setuptools_pyproject_toml, 'project', 'version'):
+                return clean_version(ver_str)
+
+
+def hatchling_dynamic_version(*, pyproject_toml: dict, pyproject_toml_path: Path) -> Version | None:
+    dynamic = dict_get(pyproject_toml, 'project', 'dynamic')
+    if dynamic and 'version' in dynamic:
+        if dict_get(pyproject_toml, 'tool', 'hatch', 'version', 'path'):
+            # Project used "dynamic metadata" from hatchling for the version
+
+            from hatchling.metadata.core import ProjectMetadata
+            from hatchling.plugin.manager import PluginManager
+
+            plugin_manager = PluginManager()
+            metadata = ProjectMetadata(root=pyproject_toml_path.parent, plugin_manager=plugin_manager)
+            version = metadata.hatch.version
+            source = version.source
+            version_data = source.get_version_data()
+            if ver_str := version_data.get('version'):
+                return clean_version(ver_str)
+
+
+def get_pyproject_toml_version(package_path: Path) -> Version | None:
     pyproject_toml_path = Path(package_path, 'pyproject.toml')
     assert_is_file(pyproject_toml_path)
 
@@ -151,13 +191,25 @@ def get_pyproject_toml_version(package_path: Path) -> Optional[Version]:
     if ver_str:
         return clean_version(ver_str)
 
+    if version := hatchling_dynamic_version(pyproject_toml=pyproject_toml, pyproject_toml_path=pyproject_toml_path):
+        return version
 
-def check_version(*, module, package_path: Path, distribution_name: Optional[str] = None) -> Version:
+    if version := setuptools_dynamic_version(pyproject_toml=pyproject_toml, pyproject_toml_path=pyproject_toml_path):
+        return version
+
+    return None
+
+
+def check_version(*, module, package_path: Path, distribution_name: str | None = None) -> Version:
     if not distribution_name:
         distribution_name = module.__name__
 
-    module_version = clean_version(module.__version__)
-    installed_version = clean_version(version(distribution_name))
+    if module_version := module.__version__:
+        module_version = clean_version(module_version)
+
+    if installed_version := version(distribution_name):
+        installed_version = clean_version(installed_version)
+
     if module_version != installed_version:
         exit_with_error(
             f'Version mismatch: current version {module_version} is not the installed one: {installed_version}',
@@ -192,10 +244,13 @@ def build(package_path) -> None:
     print('OK')
 
     if Path(package_path / 'poetry.lock').is_file():
-        # Poetry used -> build with it
+        logger.info('Poetry lock file found: build with poetry')
         output = verbose_check_output('poetry', 'build', verbose=True, exit_on_error=True)
+    elif uv_path := get_uv_path():
+        logger.info('uv found: build with uv')
+        output = verbose_check_output(uv_path, 'build', verbose=True, exit_on_error=True)
     else:
-        # use normal build
+        logger.info('use normal build')
         output = verbose_check_output(sys.executable, '-m', 'build', verbose=True, exit_on_error=True)
 
     with tempfile.NamedTemporaryFile(
@@ -209,9 +264,9 @@ def publish_package(
     *,
     module,
     package_path: Path,
-    possible_branch_names: tuple[str] = ('main', 'master'),
+    possible_branch_names: tuple[str, ...] = ('main', 'master'),
     tag_msg_log_format: str = '%h %as %s',
-    distribution_name: Optional[str] = None,  # Must be given, if it's not == module.__name__
+    distribution_name: str | None = None,  # Must be given, if it's not == module.__name__
 ) -> None:
     """
     Build and upload (with twine) a project to PyPi with many pre-checks:
